@@ -131,7 +131,7 @@ static command_rec ssl_config_cmds[] = {
                "(`none', `optional', `require', `optional_no_ca')")
     AP_ALL_CMD(VerifyDepth, TAKE1,
                "SSL Client verify depth "
-               "(`N' - number of intermediate certifcates)")
+               "(`N' - number of intermediate certificates)")
     AP_SRV_CMD(SessionCacheTimeout, TAKE1,
                "SSL Session Cache object lifetime "
                "(`N' - number of seconds)")
