@@ -109,16 +109,22 @@
  * Provide reasonable default for some defines
  */
 #ifndef FALSE
-#define FALSE 0
+#define FALSE (0)
 #endif
 #ifndef TRUE
-#define TRUE  !FALSE
+#define TRUE (!FALSE)
+#endif
+#ifndef PFALSE
+#define PFALSE ((void *)FALSE)
+#endif
+#ifndef PTRUE
+#define PTRUE ((void *)TRUE)
 #endif
 #ifndef UNSET
-#define UNSET -1
+#define UNSET (-1)
 #endif
 #ifndef NUL
-#define NUL   '\0'
+#define NUL '\0'
 #endif
 #ifndef RAND_MAX
 #include <limits.h>
@@ -629,6 +635,7 @@ BOOL         ssl_mutex_sem_release(void);
 
 /*  Logfile Support  */
 void         ssl_log_open(server_rec *, pool *);
+BOOL         ssl_log_applies(server_rec *s, int level);
 void         ssl_log(server_rec *, int, const char *, ...);
 void         ssl_die(void);
 
