@@ -525,7 +525,7 @@ const char *ssl_cmd_SSLCACertificateFile(
 
     cpPath = ap_server_root_relative(cmd->pool, arg);
     if (!ssl_util_path_check(SSL_PCM_EXISTS|SSL_PCM_ISREG|SSL_PCM_ISNONZERO, cpPath))
-        return ap_pstrcat(cmd->pool, "SSLCACertificateKeyFile: file '",
+        return ap_pstrcat(cmd->pool, "SSLCACertificateFile: file '",
                           cpPath, "' not exists or empty", NULL);
 #ifdef SSL_EXPERIMENTAL
     if (cmd->path == NULL || dc == NULL)
