@@ -135,17 +135,17 @@ static char *ssl_ext_mlc_log_c(request_rec *r, char *a)
     if (ap_ctx_get(r->connection->client->ctx, "ssl") == NULL)
         return NULL;
     result = NULL;
-    if (strcmp(a, "version") == 0)
+    if (strEQ(a, "version"))
         result = ssl_var_lookup(r->pool, r->server, r->connection, r, "SSL_PROTOCOL");
-    else if (strcmp(a, "cipher") == 0)
+    else if (strEQ(a, "cipher"))
         result = ssl_var_lookup(r->pool, r->server, r->connection, r, "SSL_CIPHER");
-    else if (strcmp(a, "subjectdn") == 0 || strcmp(a, "clientcert") == 0)
+    else if (strEQ(a, "subjectdn") || strEQ(a, "clientcert"))
         result = ssl_var_lookup(r->pool, r->server, r->connection, r, "SSL_CLIENT_S_DN");
-    else if (strcmp(a, "issuerdn") == 0 || strcmp(a, "cacert") == 0)
+    else if (strEQ(a, "issuerdn") || strEQ(a, "cacert"))
         result = ssl_var_lookup(r->pool, r->server, r->connection, r, "SSL_CLIENT_I_DN");
-    else if (strcmp(a, "errcode") == 0)
+    else if (strEQ(a, "errcode"))
         result = "-";
-    else if (strcmp(a, "errstr") == 0)
+    else if (strEQ(a, "errstr"))
         result = ap_ctx_get(r->connection->client->ctx, "ssl::verify::error");
     if (result != NULL && result[0] == NUL)
         result = NULL;
@@ -251,7 +251,7 @@ static int ssl_ext_mp_canon(request_rec *r, char *url)
 {
     int rc;
 
-    if (strncasecmp(url, "https:", 6) == 0) {
+    if (strcEQn(url, "https:", 6)) {
         rc = OK;
         ap_hook_call("ap::mod_proxy::http::canon",
                      &rc, r, url+6, "https", DEFAULT_HTTPS_PORT);
@@ -265,18 +265,21 @@ static int ssl_ext_mp_handler(
 {
     int rc;
 
-    if (strcasecmp(protocol, "https") == 0) {
-        ap_ctx_set(r->ctx, "ssl_enabled", (void *)1);
+    if (strcEQ(protocol, "https")) {
+        ap_ctx_set(r->ctx, "ssl::proxy::enabled", PTRUE);
         ap_hook_call("ap::mod_proxy::http::handler",
                      &rc, r, cr, url, proxyhost, proxyport);
         return rc;
     }
+    else {
+        ap_ctx_set(r->ctx, "ssl::proxy::enabled", PFALSE);
+    }
     return DECLINED;
 }
 
 static int ssl_ext_mp_set_destport(request_rec *r)
 {
-    if (ap_ctx_get(r->ctx, "ssl_enabled") == (void *)1)
+    if (ap_ctx_get(r->ctx, "ssl::proxy::enabled") == PTRUE)
         return DEFAULT_HTTPS_PORT;
     else
         return DEFAULT_HTTP_PORT;
@@ -288,9 +291,11 @@ static char *ssl_ext_mp_new_connection(request_rec *r, BUFF *fb)
     SSL *ssl;
     char *errmsg;
     int rc;
+    char *cpVHostID;
 
-    if (ap_ctx_get(r->ctx, "ssl_enabled") != (void *)1)
+    if (ap_ctx_get(r->ctx, "ssl::proxy::enabled") == PFALSE)
         return NULL;
+    cpVHostID = ssl_util_vhostid(r->pool, r->server);
 
     /*
      * Create a SSL context and handle
@@ -298,8 +303,15 @@ static char *ssl_ext_mp_new_connection(request_rec *r, BUFF *fb)
     ssl_ctx = SSL_CTX_new(SSLv23_client_method());
     ssl = SSL_new(ssl_ctx);
     SSL_clear(ssl);
+#if SSL_LIBRARY_VERSION >= 0x0922
+    SSL_set_session_id_context(ssl, cpVHostID, strlen(cpVHostID));
+#endif
     SSL_set_fd(ssl, fb->fd);
     ap_ctx_set(fb->ctx, "ssl", ssl);
+
+    /*
+     * Give us a chance to gracefully close the connection
+     */
     ap_register_cleanup(r->pool, (void *)fb,
                         ssl_ext_mp_close_connection, ssl_ext_mp_close_connection);
 
@@ -307,7 +319,7 @@ static char *ssl_ext_mp_new_connection(request_rec *r, BUFF *fb)
      * Establish the SSL connection
      */
     if ((rc = SSL_connect(ssl)) <= 0) {
-        errmsg = ap_pstrcat(r->pool, "SSL connect failed: ",
+        errmsg = ap_pstrcat(r->pool, "SSL connect failed (%s): ", cpVHostID,
                             ERR_reason_error_string(ERR_get_error()), NULL);
         SSL_free(ssl);
         ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -325,7 +337,7 @@ static void ssl_ext_mp_close_connection(void *_fb)
     ssl = ap_ctx_get(fb->ctx, "ssl");
     if (ssl != NULL) {
         SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
-        while (!SSL_shutdown(ssl));
+        SSL_smart_shutdown(ssl);
         SSL_free(ssl);
         ap_ctx_set(fb->ctx, "ssl", NULL);
     }
@@ -335,7 +347,7 @@ static void ssl_ext_mp_close_connection(void *_fb)
 static int ssl_ext_mp_write_host_header(
     request_rec *r, BUFF *fb, char *host, int port, char *portstr)
 {
-    if (ap_ctx_get(r->ctx, "ssl_enabled") != (void *)1)
+    if (ap_ctx_get(r->ctx, "ssl::proxy::enabled") == PFALSE)
         return DECLINED;
 
     if (portstr != NULL && port != DEFAULT_HTTPS_PORT) {
