@@ -1,7 +1,7 @@
 /*                      _             _
 **  _ __ ___   ___   __| |    ___ ___| |
 ** | '_ ` _ \ / _ \ / _` |   / __/ __| |
-** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
+** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to OpenSSL
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|
 **  ssl_engine_io.c
@@ -125,9 +125,9 @@ static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_read(ssl, buf, len);
         /*
-         * Simulate an EINTR in case SSLeay wants to read more.
+         * Simulate an EINTR in case OpenSSL wants to read more.
          * (This is usually the case when the client forces an SSL
-         * renegotation which is handled implicitly by SSLeay.)
+         * renegotation which is handled implicitly by OpenSSL.)
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_READ)
             errno = EINTR;
@@ -159,7 +159,7 @@ static int ssl_io_hook_write(BUFF *fb, char *buf, int len)
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_write(ssl, buf, len);
         /*
-         * Simulate an EINTR in case SSLeay wants to write more.
+         * Simulate an EINTR in case OpenSSL wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
@@ -195,7 +195,7 @@ static int ssl_io_hook_writev(BUFF *fb, const struct iovec *iov, int iovcnt)
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_writev(ssl, iov, iovcnt);
         /*
-         * Simulate an EINTR in case SSLeay wants to write more.
+         * Simulate an EINTR in case OpenSSL wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
@@ -257,7 +257,7 @@ static int ssl_io_hook_sendwithtimeout(BUFF *fb, const char *buf, int len)
 
 /*  _________________________________________________________________
 **
-**  Special Functions for SSLeay
+**  Special Functions for OpenSSL
 **  _________________________________________________________________
 */
 
@@ -372,8 +372,8 @@ static int SSL_recvwithtimeout(BUFF *fb, char *buf, int len)
 #endif /*WIN32*/
 
 /*
- * There is no SSL_writev() provided by SSLeay. The reason is mainly because
- * SSLeay has to fragment the data itself again for the SSL record layer, so a
+ * There is no SSL_writev() provided by OpenSSL. The reason is mainly because
+ * OpenSSL has to fragment the data itself again for the SSL record layer, so a
  * writev() like interface makes not much sense.  What we do is to emulate it
  * to at least being able to use the write() like interface. But keep in mind
  * that the network I/O performance is not write() like, of course.
@@ -453,34 +453,39 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
     return;
 }
 
-long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long len)
+long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long rc)
 {
     SSL *ssl;
     conn_rec *c;
     server_rec *s;
 
     if ((ssl = (SSL *)BIO_get_callback_arg(bio)) == NULL)
-        return len;
+        return rc;
     if ((c = (conn_rec *)SSL_get_app_data(ssl)) == NULL)
-        return len;
+        return rc;
     s = c->server;
 
-    if (len >= 0) {
-        ssl_log(s, SSL_LOG_DEBUG,
-                "%s: %s %ld/%d bytes %s BIO#%08X [mem: %08lX] %s",
-                SSL_LIBRARY_NAME, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
-                len, argi, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "to" : "from"),
-                bio, argp, (argp != NULL ? "(BIO dump follows)" : "(Ops, no memory buffer?)"));
-        if (argp != NULL)
-            ssl_io_data_dump(s, argp, len);
+    if (   cmd == (BIO_CB_WRITE|BIO_CB_RETURN) 
+        || cmd == (BIO_CB_READ |BIO_CB_RETURN) ) {
+        if (rc >= 0) {
+            ssl_log(s, SSL_LOG_DEBUG,
+                    "%s: %s %ld/%d bytes %s BIO#%08X [mem: %08lX] %s",
+                    SSL_LIBRARY_NAME, 
+                    (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
+                    rc, argi, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "to" : "from"),
+                    bio, argp, 
+                    (argp != NULL ? "(BIO dump follows)" : "(Ops, no memory buffer?)"));
+            if (argp != NULL)
+                ssl_io_data_dump(s, argp, rc);
+        }
+        else {
+            ssl_log(s, SSL_LOG_DEBUG,
+                    "%s: I/O error, %d bytes expected to %s on BIO#%08X [mem: %08lX]",
+                    SSL_LIBRARY_NAME, argi, 
+                    (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
+                    bio, argp);
+        }
     }
-    else {
-        ssl_log(s, SSL_LOG_DEBUG,
-                "%s: I/O error, %d bytes expected to %s on BIO#%08X [mem: %08lX]",
-                SSL_LIBRARY_NAME, argi, 
-                (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
-                bio, argp);
-    }
-    return len;
+    return rc;
 }
 
