@@ -480,13 +480,13 @@ void ssl_hook_CloseConnection(conn_rec *conn)
      * exchange close notify messages, but allow the user
      * to force the type of handshake via SetEnvIf directive
      */
-    if (ap_ctx_get(conn->client->ctx, "ssl::flag::unclean-shutdown") == (void *)1) {
+    if (ap_ctx_get(conn->client->ctx, "ssl::flag::unclean-shutdown") == PTRUE) {
         /* perform no close notify handshake at all 
            (violates the SSL/TLS standard!) */
         SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
         cpType = "unclean";
     }
-    else if (ap_ctx_get(conn->client->ctx, "ssl::flag::accurate-shutdown") == (void *)1) {
+    else if (ap_ctx_get(conn->client->ctx, "ssl::flag::accurate-shutdown") == PTRUE) {
         /* send close notify and wait for clients close notify 
            (standard compliant, but usually causes connection hangs) */
         SSL_set_shutdown(ssl, 0);
@@ -568,13 +568,13 @@ int ssl_hook_Translate(request_rec *r)
      * to allow the close connection handler to use them.
      */
     if (ap_table_get(r->subprocess_env, "ssl-unclean-shutdown") != NULL)
-        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", (void *)1);
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", PTRUE);
     else
-        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", (void *)0);
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::unclean-shutdown", PFALSE);
     if (ap_table_get(r->subprocess_env, "ssl-accurate-shutdown") != NULL)
-        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", (void *)1);
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", PTRUE);
     else
-        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", (void *)0);
+        ap_ctx_set(r->connection->client->ctx, "ssl::flag::accurate-shutdown", PFALSE);
 
     return DECLINED;
 }
