@@ -193,7 +193,7 @@ int SSL_smart_shutdown(SSL *ssl)
      * connection and OpenSSL cannot recognize it.
      */
     rc = 0;
-    for (i = 0; i < 8 /* max 2x pending + 2x data = 4, and double it */; i++) {
+    for (i = 0; i < 4 /* max 2x pending + 2x data = 4 */; i++) {
         if ((rc = SSL_shutdown(ssl)))
             break;
     }
