@@ -100,5 +100,8 @@
 int    SSL_get_app_data2_idx(void);
 void  *SSL_get_app_data2(SSL *);
 void   SSL_set_app_data2(SSL *, void *);
+X509  *SSL_read_X509(FILE *, X509 **, int (*)());
+RSA   *SSL_read_RSAPrivateKey(FILE *, RSA **, int (*)());
+int    SSL_smart_shutdown(SSL *ssl);
 
 #endif /* SSL_UTIL_SSL_H */
